@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Arrangement_on_surface_2/include/CGAL/Arr_vertical_decomposition_2.h $
-// $Id: Arr_vertical_decomposition_2.h 3c5552b 2020-06-30T21:22:40+03:00 Efi Fogel
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Arrangement_on_surface_2/include/CGAL/Arr_vertical_decomposition_2.h $
+// $Id: Arr_vertical_decomposition_2.h 014c06f 2022-11-14T15:32:47+01:00 albert-github
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s): Ron Wein <wein@post.tau.ac.il>
@@ -87,7 +87,7 @@ decompose(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
     Halfedge_const_handle he = (eit->direction() == ARR_RIGHT_TO_LEFT) ?
       eit : eit->twin();
     //attempt to solve compile problem in one of the tests. created the
-    // tmp_curve instead of passing eit->curve() as a parmeter to the function
+    // tmp_curve instead of passing eit->curve() as a parameter to the function
     X_monotone_curve_2 tmp_curve = eit->curve();
     xcurves_vec[i++] = Vd_x_monotone_curve_2(tmp_curve, he);
   }
@@ -102,7 +102,7 @@ decompose(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
     if (vit->is_isolated()) {
       Vertex_const_handle iso_v = vit;
       //attempt to solve compile problem in one of the tests. created the
-      // tmp_curve instead of passing eit->curve() as a parmeter to the
+      // tmp_curve instead of passing eit->curve() as a parameter to the
       // function
       Point_2 tmp_point = vit->point();
       iso_pts_vec[i++] = Vd_point_2(tmp_point, iso_v);
@@ -124,7 +124,7 @@ decompose(const Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
    * Use the form 'A a(*b);' and not ''A a = b;' to handle the case where A has
    * only an implicit constructor, (which takes *b as a parameter).
    */
-  typename boost::mpl::if_<boost::is_same<Gt2, Vgt2>, const Vgt2&, Vgt2>::type
+  typename boost::mpl::if_<std::is_same<Gt2, Vgt2>, const Vgt2&, Vgt2>::type
     ex_traits(*geom_traits);
 
   // Define the sweep-line visitor and perform the sweep.
