@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Intersections_2/include/CGAL/Intersections_2/Line_2_Segment_2.h $
-// $Id: Line_2_Segment_2.h d370326 2021-10-27T14:45:10+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Intersections_2/include/CGAL/Intersections_2/Line_2_Segment_2.h $
+// $Id: Line_2_Segment_2.h 8ba0b41 2022-11-22T12:35:10+01:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -51,14 +51,25 @@ protected:
 };
 
 template <class K>
-inline bool do_intersect(
-    const typename K::Segment_2 &p1,
-    const typename K::Line_2 &p2,
-    const K&)
+inline
+typename K::Boolean
+do_intersect(const typename K::Segment_2& s,
+             const typename K::Line_2& l,
+             const K& )
 {
-    typedef Segment_2_Line_2_pair<K> pair_t;
-    pair_t pair(&p1, &p2);
-    return pair.intersection_type() != pair_t::NO_INTERSECTION;
+  typedef Segment_2_Line_2_pair<K> pair_t;
+  pair_t pair(&s, &l);
+  return pair.intersection_type() != pair_t::NO_INTERSECTION;
+}
+
+template <class K>
+inline
+typename K::Boolean
+do_intersect(const typename K::Line_2& l,
+             const typename K::Segment_2& s,
+             const K& k)
+{
+  return internal::do_intersect(s, l, k);
 }
 
 template <class K>
@@ -92,17 +103,6 @@ intersection(const typename K::Line_2 &line,
   return internal::intersection(seg, line, k);
 }
 
-
-template <class K>
-inline bool do_intersect(
-    const typename K::Line_2 &line,
-    const typename K::Segment_2 &seg,
-    const K& k)
-{
-  return internal::do_intersect(seg, line, k);
-}
-
-
 template <class K>
 typename Segment_2_Line_2_pair<K>::Intersection_results
 Segment_2_Line_2_pair<K>::intersection_type() const
@@ -156,7 +156,6 @@ Segment_2_Line_2_pair<K>::intersection_segment() const
 CGAL_INTERSECTION_FUNCTION(Segment_2, Line_2, 2)
 CGAL_DO_INTERSECT_FUNCTION(Segment_2, Line_2, 2)
 
+} // namespace CGAL
 
-} //namespace CGAL
-
-#endif
+#endif // CGAL_INTERSECTIONS_2_SEGMENT_2_LINE_2_H
