@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Optimal_bounding_box/include/CGAL/Optimal_bounding_box/oriented_bounding_box.h $
-// $Id: oriented_bounding_box.h 2c6d70e 2022-10-07T15:46:37+02:00 Laurent Rineau
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Optimal_bounding_box/include/CGAL/Optimal_bounding_box/oriented_bounding_box.h $
+// $Id: oriented_bounding_box.h fec38fe 2023-05-31T15:42:06+02:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -37,7 +37,6 @@
 
 #include <boost/iterator/transform_iterator.hpp>
 #include <boost/range/value_type.hpp>
-#include <boost/utility/enable_if.hpp>
 
 #include <array>
 #include <iostream>
@@ -164,9 +163,9 @@ void construct_oriented_bounding_box(const PointRange& points,
                                      Array& obb_points,
                                      CGAL::Random& rng,
                                      const Traits& traits,
-                                     typename boost::enable_if<
-                                       typename boost::has_range_iterator<Array>
-                                     >::type* = 0)
+                                     std::enable_if_t<
+                                       boost::has_range_iterator<Array>::value
+                                     >* = 0)
 {
   typename Traits::Aff_transformation_3 transformation, inverse_transformation;
   compute_best_transformation(points, transformation, inverse_transformation, rng, traits);
@@ -179,9 +178,9 @@ void construct_oriented_bounding_box(const PointRange& points,
                                      PolygonMesh& pm,
                                      CGAL::Random& rng,
                                      const Traits& traits,
-                                     typename boost::disable_if<
-                                       typename boost::has_range_iterator<PolygonMesh>
-                                     >::type* = 0)
+                                     std::enable_if_t<
+                                       !boost::has_range_iterator<PolygonMesh>::value
+                                     >* = 0)
 {
   typename Traits::Aff_transformation_3 transformation, inverse_transformation;
   compute_best_transformation(points, transformation, inverse_transformation, rng, traits);
@@ -318,9 +317,9 @@ void oriented_bounding_box(const PointRange& points,
                            Output& out,
                            const NamedParameters& np = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-                           , typename boost::enable_if<
-                               typename boost::has_range_iterator<PointRange>
-                           >::type* = 0
+                           , std::enable_if_t<
+                               boost::has_range_iterator<PointRange>::value
+                           >* = 0
 #endif
                            )
 {
@@ -362,7 +361,7 @@ void oriented_bounding_box(const PointRange& points,
   // @todo handle those cases (or call min_rectangle_2 with a projection)
   if(points.size() <= 3)
   {
-    std::cerr << "The oriented bounding box cannot (yet) be computed for a mesh with fewer than 4 vertices!\n";
+    std::cerr << "The oriented bounding box cannot be computed with fewer than 4 vertices!\n";
     return;
   }
 
@@ -421,9 +420,9 @@ void oriented_bounding_box(const PolygonMesh& pmesh,
                            Output& out,
                            const NamedParameters& np = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-                           , typename boost::disable_if<
-                              typename boost::has_range_iterator<PolygonMesh>
-                           >::type* = 0
+                           , std::enable_if_t<
+                              !boost::has_range_iterator<PolygonMesh>::value
+                           >* = 0
 #endif
                            )
 {
