@@ -3,8 +3,8 @@
 // This file is part of CGAL (www.cgal.org).
 //
 
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Straight_skeleton_2/include/CGAL/arrange_offset_polygons_2.h $
-// $Id: arrange_offset_polygons_2.h 314db57 2020-11-06T12:03:15+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Straight_skeleton_2/include/CGAL/arrange_offset_polygons_2.h $
+// $Id: arrange_offset_polygons_2.h 66fe079 2023-03-23T11:49:18+01:00 Mael Rouxel-Labbé
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
@@ -46,9 +46,6 @@ bool arrange_offset_polygons_2 ( InputPolygonPtrIterator           aBegin
                                , const K&
                                )
 {
-  bool bk_poly_assert_mode = get_use_polygon_assertions();
-  set_use_polygon_assertions(false); // disable assertions in Polygon_2 function as we may manipulate strictly simple polygons
-
   typedef typename std::iterator_traits<InputPolygonPtrIterator>::difference_type difference_type ;
   typedef typename std::iterator_traits<InputPolygonPtrIterator>::value_type PolygonPtr ;
 
@@ -64,7 +61,9 @@ bool arrange_offset_polygons_2 ( InputPolygonPtrIterator           aBegin
 
     const PolygonPtr lPoly = *it ;
 
-    Orientation lOrient = lPoly->orientation();
+    Orientation lOrient = CGAL::Polygon::internal::orientation_2_no_precondition(lPoly->vertices().begin(),
+                                                                                 lPoly->vertices().end(),
+                                                                                 lPoly->traits_member());
 
     // It's an outer boundary
     if ( lOrient == COUNTERCLOCKWISE )
@@ -99,15 +98,12 @@ bool arrange_offset_polygons_2 ( InputPolygonPtrIterator           aBegin
       }
 
       if (lParent == nullptr)
-      {
-        set_use_polygon_assertions(bk_poly_assert_mode);
         return false;
-      }
 
       lParent->add_hole(*lPoly);
     }
   }
-  set_use_polygon_assertions(bk_poly_assert_mode);
+
   return true;
 }
 
@@ -141,6 +137,6 @@ arrange_offset_polygons_2 ( std::vector<boost::shared_ptr<Polygon> > const& aPol
   return arrange_offset_polygons_2<PolygonWithHoles>(aPolygons, no_error);
 }
 
-} // end namespace CGAL
+} // namespace CGAL
 
 #endif // CGAL_ARRANGE_OFFSET_POLYGONS_2_H
