@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/BGL/include/CGAL/boost/graph/copy_face_graph.h $
-// $Id: copy_face_graph.h 4ffc949 2022-02-03T17:11:20+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/BGL/include/CGAL/boost/graph/copy_face_graph.h $
+// $Id: copy_face_graph.h 861588a 2022-08-03T20:19:51+02:00 Sébastien Loriot
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -23,8 +23,6 @@
 #include <CGAL/Named_function_parameters.h>
 #include <CGAL/boost/graph/named_params_helper.h>
 #include <CGAL/property_map.h>
-#include <boost/utility/enable_if.hpp>
-#include <boost/iterator/function_output_iterator.hpp>
 
 #include <unordered_map>
 
@@ -213,36 +211,6 @@ void copy_face_graph_impl(const SourceMesh& sm, TargetMesh& tm,
 }
 
 } // end of namespace internal
-namespace impl
-{
-template<typename PMAP>
-struct Output_iterator_functor
-{
-  typedef typename boost::property_traits<PMAP>::key_type input_t;
-  typedef typename boost::property_traits<PMAP>::value_type output_t;
-  PMAP map;
-  Output_iterator_functor(PMAP map)
-    :map(map)
-  {
-  }
-  void operator()(const typename std::pair<input_t, output_t>& pair)
-  {
-    put(map, pair.first, pair.second);
-  }
-
-};
-
-template<typename PMAP>
-boost::function_output_iterator<Output_iterator_functor<PMAP> > make_functor(PMAP map)
-{
-  return boost::make_function_output_iterator(Output_iterator_functor<PMAP>(map));
-}
-
-inline Emptyset_iterator make_functor(const internal_np::Param_not_found&)
-{
-  return Emptyset_iterator();
-}
-}//end of impl
 
 /*!
   \ingroup PkgBGLHelperFct
