@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Principal_component_analysis_LGPL/include/CGAL/centroid.h $
-// $Id: centroid.h 5e72746 2020-10-29T14:15:38+01:00 Simon Giraudot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Principal_component_analysis_LGPL/include/CGAL/centroid.h $
+// $Id: centroid.h 70a06b4 2022-06-27T08:58:17+01:00 Andreas Fabri
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -20,11 +20,12 @@
 #include <CGAL/Origin.h>
 #include <CGAL/Kernel/global_functions.h>
 
-#include <CGAL/is_iterator.h>
+#include <CGAL/type_traits/is_iterator.h>
 #include <boost/utility.hpp>
 
 #include <iterator>
 #include <list>
+#include <type_traits>
 
 // Functions to compute the centroid of N points.
 // Works in 2D and 3D.
@@ -822,7 +823,7 @@ struct Dispatch_centroid_3
 
 template < typename InputIterator, typename K>
 typename internal::Dispatch_centroid_3<
-  typename boost::enable_if<is_iterator<InputIterator>,InputIterator>::type,
+  std::enable_if_t<is_iterator<InputIterator>::value,InputIterator>,
   K,Dynamic_dimension_tag>::result_type
 centroid(InputIterator begin, InputIterator end, const K& k, Dynamic_dimension_tag tag)
 {
@@ -831,7 +832,7 @@ centroid(InputIterator begin, InputIterator end, const K& k, Dynamic_dimension_t
 
 template < typename InputIterator, typename K, int d >
 typename internal::Dispatch_centroid_3<
-  typename boost::enable_if<is_iterator<InputIterator>,InputIterator>::type,
+  std::enable_if_t<is_iterator<InputIterator>::value,InputIterator>,
   K,Dimension_tag<d> >::result_type
 centroid(InputIterator begin, InputIterator end, const K& k, Dimension_tag<d> tag)
 {
@@ -896,7 +897,7 @@ struct Dispatch_centroid <InputIterator, Dynamic_dimension_tag>
 template < typename InputIterator, typename Kernel_or_dim >
 inline
 typename internal::Dispatch_centroid<
-  typename boost::enable_if<is_iterator<InputIterator>,InputIterator>::type,
+  std::enable_if_t<is_iterator<InputIterator>::value,InputIterator>,
   Kernel_or_dim>::result_type
 centroid(InputIterator begin, InputIterator end, const Kernel_or_dim& k_or_d)
 {
@@ -905,7 +906,7 @@ centroid(InputIterator begin, InputIterator end, const Kernel_or_dim& k_or_d)
 }
 
 namespace internal {
-template<class It,bool=is_iterator<It>::value>
+  template<class It,bool=is_iterator<It>::value>
 class Centroid_2args_return_type_helper{};
 
 template<class It>
