@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Number_types/include/CGAL/mpz_class.h $
-// $Id: mpz_class.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Number_types/include/CGAL/mpz_class.h $
+// $Id: mpz_class.h 3fa4364 2022-06-10T08:41:19+02:00 Sébastien Loriot
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -32,13 +32,14 @@
 #include <CGAL/Real_embeddable_traits.h>
 #include <CGAL/number_utils.h>
 #include <CGAL/double.h>
-#include <boost/type_traits/is_same.hpp>
 #include <mpfr.h>
 #include <gmpxx.h>
 
+#include <type_traits>
+
 #define CGAL_CHECK_GMP_EXPR                                             \
     CGAL_static_assertion(                                                \
-            (::boost::is_same< ::__gmp_expr< T , T >,Type>::value ));
+            (::std::is_same< ::__gmp_expr< T , T >,Type>::value ));
 
 namespace CGAL {
 
