@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Point_set_processing_3/include/CGAL/wlop_simplify_and_regularize_point_set.h $
-// $Id: wlop_simplify_and_regularize_point_set.h 75b03e6 2022-01-10T15:33:04+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v5.6/Point_set_processing_3/include/CGAL/wlop_simplify_and_regularize_point_set.h $
+// $Id: wlop_simplify_and_regularize_point_set.h d3fca65 2022-09-23T12:49:40+01:00 Andreas Fabri
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Shihao Wu, Clement Jamin, Pierre Alliez
@@ -19,7 +19,7 @@
 #include <CGAL/Search_traits_3.h>
 #include <CGAL/Orthogonal_k_neighbor_search.h>
 #include <CGAL/property_map.h>
-#include <CGAL/point_set_processing_assertions.h>
+#include <CGAL/assertions.h>
 #include <CGAL/Memory_sizer.h>
 #include <CGAL/compute_average_spacing.h>
 
@@ -105,7 +105,7 @@ compute_update_sample_point(
   const std::vector<typename Kernel::FT>& sample_densities ///<
 )
 {
-  CGAL_point_set_processing_precondition(radius > 0);
+  CGAL_precondition(radius > 0);
   bool is_original_densities_empty = original_densities.empty();
   bool is_sample_densities_empty = sample_densities.empty();
 
@@ -231,7 +231,7 @@ compute_density_weight_for_original_point(
   const typename Kernel::FT radius       ///< neighbor radius square
 )
 {
-  CGAL_point_set_processing_precondition(radius > 0);
+  CGAL_precondition(radius > 0);
 
   // basic geometric types
   typedef typename Kernel::Point_3                         Point;
@@ -465,9 +465,9 @@ wlop_simplify_and_regularize_point_set(
   // precondition: at least one element in the container.
   // to fix: should have at least three distinct points
   // but this is costly to check
-  CGAL_point_set_processing_precondition(points.begin() != points.end());
-  CGAL_point_set_processing_precondition(select_percentage >= 0
-                                         && select_percentage <= 100);
+  CGAL_precondition(points.begin() != points.end());
+  CGAL_precondition(select_percentage >= 0
+                    && select_percentage <= 100);
 
   // Random shuffle
   CGAL::cpp98::random_shuffle (points.begin(), points.end());
@@ -507,7 +507,7 @@ wlop_simplify_and_regularize_point_set(
 #endif
   }
 
-  CGAL_point_set_processing_precondition(radius > 0);
+  CGAL_precondition(radius > 0);
 
   // Initiate a KD-tree search for original points
   std::vector<Kd_tree_element> original_treeElements;
